@@ -41,6 +41,15 @@ from huggingface_hub import create_repo
 
 
 
+def get_full_repo_name(model_id: str, organization: Optional[str] = None, token: Optional[str] = None):
+    if token is None:
+        token = HfFolder.get_token()
+    if organization is None:
+        username = whoami(token)["name"]
+        return f"{username}/{model_id}"
+    else:
+        return f"{organization}/{model_id}"
+
 @dataclass
 class DreamBoothConfig():
     """
@@ -48,6 +57,7 @@ class DreamBoothConfig():
     """
     # saved model
     model_out_dir: str      # directory to save the model in
+    hub_model_id: str       # huggingface repo to keep in sync with local model_out_dir
     push_to_hub: bool       # whether to push the saved model to the Huggingface Hub
     private_repo: bool      # whether to make the model repo private
 
@@ -333,28 +343,26 @@ class DreamBoothRunner():
         else:
             self.auth_token = getpass.getpass(prompt='HuggingFace access token:')
 
-        # Create a huggingface repo
-        if self.config.push_to_hub:
-            def get_full_repo_name(model_id: str, organization: Optional[str] = None, token: Optional[str] = None):
-                if token is None:
-                    token = HfFolder.get_token()
-                if organization is None:
-                    username = whoami(token)["name"]
-                    return f"{username}/{model_id}"
+        # Handle the huggingface repository creation
+        if self.accelerator.is_main_process:
+            if self.config.push_to_hub:
+                if self.config.hub_model_id is None:
+                    repo_name = get_full_repo_name(Path(self.config.output_dir).name, token=self.auth_token)
                 else:
-                    return f"{organization}/{model_id}"
+                    repo_name = self.config.hub_model_id
 
-            # Handle the repository creation
-            repo_name = get_full_repo_name(Path(self.config.model_out_dir).name, token=self.auth_token)
-            print(f'Creating repo: {repo_name}')
+                print('Repo name will be: ', repo_name)
+                self.repo = Repository(self.config.model_out_dir, clone_from=repo_name)
+                print('Created repo at Run.repo')
 
-            create_repo(repo_name, token=self.auth_token, exist_ok=True)
-            self.repo = Repository(self.config.model_out_dir, clone_from=repo_name, token=self.auth_token, private=self.config.private_repo)
-            with open(os.path.join(self.config.model_out_dir, ".gitignore"), "w+") as gitignore:
-                if "step_*" not in gitignore:
-                    gitignore.write("step_*\n")
-                if "epoch_*" not in gitignore:
-                    gitignore.write("epoch_*\n")
+                with open(os.path.join(self.config.model_out_dir, ".gitignore"), "w+") as gitignore:
+                    if "step_*" not in gitignore:
+                        gitignore.write("step_*\n")
+                    if "epoch_*" not in gitignore:
+                        gitignore.write("epoch_*\n")
+            elif self.config.model_out_dir is not None:
+                print('hit condition line 355')
+                os.makedirs(self.config.model_out_dir, exist_ok=True)
 
 
         print('Starting Accelerator')
@@ -759,7 +767,9 @@ class DreamBoothRunner():
             pipeline.save_pretrained(self.config.model_out_dir)
 
             if self.config.push_to_hub:
+                print('Pushing to hub...')
                 self.repo.push_to_hub(commit_message="End of training", blocking=False, auto_lfs_prune=True)
+                print('Pushed to hub')
 
         self.accelerator.end_training()
         print('Training done')
